@@ -6,9 +6,14 @@ import pkg_resources
 
 def get_gunicorn_cmd(site_config, bin_dir=''):
     gconfig = copy.copy(site_config['gunicorn'])
-    #default to using a unix socket for nginx->gunicorn
-    if 'bind' not in gconfig:
-        gconfig['bind'] = 'unix:/tmp/%s.sock' % site_config['site']
+
+    # Default to using a unix socket for nginx->gunicorn
+    gconfig['bind'] = gconfig.get('bind', 
+                                  'unix:/tmp/%s.sock' % site_config['site'])
+    
+    # Default to using the site name in the procname
+    gconfig['name'] = gconfig.get('name', site_config['site'])
+
     debug = gconfig.pop('debug', None)
     options = ' '.join(['--%s %s' % (x, y) for x, y in gconfig.iteritems()])
     if debug:
